@@ -11,8 +11,8 @@
 
 namespace dht
 {
-/**
- * Announce request in the DHT protocol
+/*!
+ * \brief Announce request in the DHT protocol.
  */
 class KTORRENT_EXPORT AnnounceReq : public GetPeersReq
 {
@@ -35,8 +35,6 @@ public:
         return port;
     }
 
-    typedef QSharedPointer<AnnounceReq> Ptr;
-
 private:
     bt::Uint16 port;
     QByteArray token;
