@@ -68,8 +68,8 @@ std::pair<KBucket::Ptr, KBucket::Ptr> KBucket::split() noexcept(false)
     if (m == min_key || m + 1 == max_key)
         throw UnableToSplit();
 
-    KBucket::Ptr left(new KBucket(min_key, m, srv, our_id));
-    KBucket::Ptr right(new KBucket(m + 1, max_key, srv, our_id));
+    auto left = std::make_unique<KBucket>(min_key, m, srv, our_id);
+    auto right = std::make_unique<KBucket>(m + 1, max_key, srv, our_id);
 
     QList<KBucketEntry>::iterator i;
     for (i = entries.begin(); i != entries.end(); ++i) {
@@ -80,7 +80,7 @@ std::pair<KBucket::Ptr, KBucket::Ptr> KBucket::split() noexcept(false)
             right->insert(e);
     }
 
-    return std::make_pair(left, right);
+    return std::make_pair(std::move(left), std::move(right));
 }
 
 bool KBucket::insert(const KBucketEntry &entry)
@@ -114,7 +114,7 @@ bool KBucket::insert(const KBucketEntry &entry)
     return false;
 }
 
-void KBucket::onResponse(RPCCall *c, RPCMsg::Ptr rsp)
+void KBucket::onResponse(RPCCall *c, RPCMsg *rsp)
 {
     Q_UNUSED(rsp);
     last_modified = bt::CurrentTime();
@@ -178,9 +178,9 @@ void KBucket::pingQuestionable(const KBucketEntry &replacement_entry)
         KBucketEntry &e = *i;
         if (e.isQuestionable()) {
             Out(SYS_DHT | LOG_DEBUG) << "Pinging questionable node : " << e.getAddress().toString() << endl;
-            RPCMsg::Ptr p(new PingReq(our_id));
+            auto p = std::make_unique<PingReq>(our_id);
             p->setDestination(e.getAddress());
-            RPCCall *c = srv->doCall(p);
+            RPCCall *c = srv->doCall(std::move(p));
             if (c) {
                 e.onPingQuestionable();
                 c->addListener(this);
