@@ -31,8 +31,6 @@ public:
     Private(RPCServer *srv)
         : srv(srv)
     {
-        num_receives = 0;
-        new_key = false;
     }
 
     ~Private()
@@ -77,15 +75,14 @@ public:
     QScopedPointer<KBucketTable> ipv4_table;
     QScopedPointer<KBucketTable> ipv6_table;
     RPCServer *srv;
-    Uint32 num_receives;
-    bool new_key;
+    Uint32 num_receives = 0;
+    bool new_key = false;
 };
 
 Node::Node(RPCServer *srv, const QString &key_file)
     : d(std::make_unique<Private>(srv))
+    , our_id(d->loadKey(key_file))
 {
-    num_entries = 0;
-    our_id = d->loadKey(key_file);
     d->ipv4_table.reset(new KBucketTable(our_id));
     d->ipv6_table.reset(new KBucketTable(our_id));
 }
@@ -119,12 +116,12 @@ void Node::findKClosestNodes(KClosestNodesSearch &kns, bt::Uint32 want)
         d->ipv6_table->findKClosestNodes(kns);
 }
 
-void Node::onTimeout(RPCMsg::Ptr msg)
+void Node::onTimeout(const RPCMsg &msg)
 {
-    if (msg->getOrigin().ipVersion() == 4)
-        d->ipv4_table->onTimeout(msg->getOrigin());
+    if (msg.getOrigin().ipVersion() == 4)
+        d->ipv4_table->onTimeout(msg.getOrigin());
     else
-        d->ipv6_table->onTimeout(msg->getOrigin());
+        d->ipv6_table->onTimeout(msg.getOrigin());
 }
 
 void Node::refreshBuckets(DHT *dh_table)
