@@ -56,13 +56,13 @@ public:
     void listen(const QString &ip)
     {
         net::Address addr(ip, port);
-        net::ServerSocket::Ptr sock(new net::ServerSocket(this));
+        auto sock = std::make_unique<net::ServerSocket>(this);
         if (!sock->bind(addr)) {
             Out(SYS_DHT | LOG_IMPORTANT) << "DHT: Failed to bind to " << addr.toString() << endl;
         } else {
             Out(SYS_DHT | LOG_NOTICE) << "DHT: Bound to " << addr.toString() << endl;
-            sockets.append(sock);
             sock->setReadNotificationsEnabled(true);
+            sockets.emplace_back(std::move(sock));
         }
     }
 
@@ -77,7 +77,7 @@ public:
                 return;
 
             // try to make a RPCMsg of it
-            RPCMsg::Ptr msg = factory.build(dict.get(), this);
+            std::unique_ptr<RPCMsg> msg = factory.build(dict.get(), this);
             if (msg) {
                 if (addr.ipVersion() == 6 && addr.isIPv4Mapped())
                     msg->setOrigin(addr.convertIPv4Mapped());
@@ -89,7 +89,7 @@ public:
                 if (msg->getType() == RSP_MSG && calls.contains(msg->getMTID())) {
                     // delete the call, but first notify it off the response
                     RPCCall *c = calls.find(msg->getMTID());
-                    c->response(msg);
+                    c->response(msg.get());
                     calls.erase(msg->getMTID());
                     c->deleteLater();
                     doQueuedCalls();
@@ -116,7 +116,7 @@ public:
 
     void send(const net::Address &addr, const QByteArray &msg)
     {
-        for (net::ServerSocket::Ptr sock : std::as_const(sockets)) {
+        for (const net::ServerSocket::Ptr &sock : std::as_const(sockets)) {
             if (sock->sendTo((const bt::Uint8 *)msg.data(), msg.size(), addr) == msg.size())
                 break;
         }
@@ -131,17 +131,17 @@ public:
             while (calls.contains(QByteArray(1, next_mtid)))
                 next_mtid++;
 
-            RPCMsg::Ptr msg = c->getRequest();
+            RPCMsg *msg = c->getRequest();
             QByteArray mtid(1, next_mtid);
             msg->setMTID(mtid);
             next_mtid++;
-            sendMsg(msg);
+            sendMsg(*msg);
             calls.insert(msg->getMTID(), c);
             c->start();
         }
     }
 
-    RPCCall *doCall(RPCMsg::Ptr msg)
+    RPCCall *doCall(std::unique_ptr<RPCMsg> msg)
     {
         Uint8 start = next_mtid;
         QByteArray mtid(1, start);
@@ -150,7 +150,7 @@ public:
             mtid[0] = ++next_mtid;
             if (next_mtid == start) { // if this happens we cannot do any calls
                 // so queue the call
-                RPCCall *c = new RPCCall(msg, true);
+                RPCCall *c = new RPCCall(std::move(msg), true);
                 call_queue.append(c);
                 Out(SYS_DHT | LOG_NOTICE) << "Queueing RPC call, no slots available at the moment" << endl;
                 return c;
@@ -158,17 +158,17 @@ public:
         }
 
         msg->setMTID(mtid);
-        sendMsg(msg);
-        RPCCall *c = new RPCCall(msg, false);
+        sendMsg(*msg);
+        RPCCall *c = new RPCCall(std::move(msg), false);
         calls.insert(mtid, c);
         return c;
     }
 
-    void sendMsg(RPCMsg::Ptr msg)
+    void sendMsg(const RPCMsg &msg)
     {
         QByteArray data;
-        msg->encode(data);
-        send(msg->getDestination(), data);
+        msg.encode(data);
+        send(msg.getDestination(), data);
         //  PrintRawData(data);
     }
 
@@ -177,7 +177,7 @@ public:
         // delete the call
         RPCCall *c = calls.find(mtid);
         if (c) {
-            dh_table->timeout(c->getRequest());
+            dh_table->timeout(*c->getRequest());
             calls.erase(mtid);
             c->deleteLater();
         }
@@ -185,7 +185,7 @@ public:
     }
 
     RPCServer *p;
-    QList<net::ServerSocket::Ptr> sockets;
+    std::vector<net::ServerSocket::Ptr> sockets;
     DHT *dh_table;
     bt::PtrMap<QByteArray, RPCCall> calls;
     QList<RPCCall *> call_queue;
@@ -213,13 +213,13 @@ void RPCServer::start()
         d->listen(addr);
     }
 
-    if (d->sockets.count() == 0) {
+    if (d->sockets.empty()) {
         // Try all addresses if the previous listen calls all failed
         d->listen(QHostAddress(QHostAddress::AnyIPv6).toString());
         d->listen(QHostAddress(QHostAddress::Any).toString());
     }
 
-    if (d->sockets.count() > 0)
+    if (!d->sockets.empty())
         bt::Globals::instance().getPortList().addNewPort(d->port, net::UDP, true);
 }
 
@@ -245,27 +245,20 @@ static void PrintRawData(const QByteArray & data)
 }
 #endif
 
-RPCCall *RPCServer::doCall(RPCMsg::Ptr msg)
+RPCCall *RPCServer::doCall(std::unique_ptr<RPCMsg> msg)
 {
-    RPCCall *c = d->doCall(msg);
+    RPCCall *c = d->doCall(std::move(msg));
     if (c)
         connect(c, &RPCCall::timeout, this, &RPCServer::callTimeout);
 
     return c;
 }
 
-void RPCServer::sendMsg(RPCMsg::Ptr msg)
+void RPCServer::sendMsg(const RPCMsg &msg)
 {
     d->sendMsg(msg);
 }
 
-void RPCServer::sendMsg(const dht::RPCMsg &msg)
-{
-    QByteArray data;
-    msg.encode(data);
-    d->send(msg.getDestination(), data);
-}
-
 void RPCServer::callTimeout(RPCCall *call)
 {
     d->timedOut(call->getRequest()->getMTID());
@@ -273,9 +266,9 @@ void RPCServer::callTimeout(RPCCall *call)
 
 void RPCServer::ping(const dht::Key &our_id, const net::Address &addr)
 {
-    RPCMsg::Ptr pr(new PingReq(our_id));
+    auto pr = std::make_unique<PingReq>(our_id);
     pr->setOrigin(addr);
-    doCall(pr);
+    doCall(std::move(pr));
 }
 
 Uint32 RPCServer::getNumActiveRPCCalls() const
