@@ -43,10 +43,9 @@ static void DeleteEmptyDirs(const QString &output_dir, const QString &fpath);
 
 MultiFileCache::MultiFileCache(Torrent &tor, const QString &tmpdir, const QString &datadir, bool custom_output_name)
     : Cache(tor, tmpdir, datadir)
+    , cache_dir(tmpdir + "cache"_L1 + bt::DirSeparator())
     , opened(false)
 {
-    cache_dir = tmpdir + "cache"_L1 + bt::DirSeparator();
-
     if (!custom_output_name)
         output_dir = this->datadir + tor.getNameSuggestion() + bt::DirSeparator();
     else
@@ -727,7 +726,7 @@ static void DeleteEmptyDirs(const QString &output_dir, const QString &fpath)
     while (sl.count() > 0) {
         QString path = output_dir;
         // reassemble the full directory path
-        for (const QString &s : sl)
+        for (const QString &s : std::as_const(sl))
             path += s + bt::DirSeparator();
 
         QDir dir(path);
