@@ -18,7 +18,8 @@ namespace bt
 /*!
  * \author Joris Guisson
  *
- * Simple HTTP request class.
+ * \brief Simple HTTP request class.
+ *
  * TODO: switch to KIO for this
  */
 class HTTPRequest : public bt::ExitOperation
@@ -68,7 +69,7 @@ Q_SIGNALS:
      * An OK reply was sent.
      * \param r The sender of the request
      */
-    void result(HTTPRequest *r);
+    void result(bt::HTTPRequest *r);
 
 public:
     void replyFinished();
