@@ -25,14 +25,16 @@
 #include <net/wakeuppipe.h>
 #include <util/ptrmap.h>
 
+#include <memory>
+
 namespace utp
 {
 class UTPServerThread;
 
 /*!
-    Utility class used by UTPServer to make sure that ServerInterface::newConnection is called
-    from the main thread and not from UTP thread (which is dangerous).
-*/
+ * \brief Utility class used by UTPServer to make sure that ServerInterface::newConnection is called
+ * from the main thread and not from UTP thread (which is dangerous).
+ */
 class MainThreadCall : public QObject
 {
     Q_OBJECT
@@ -83,7 +85,7 @@ public:
 
 public:
     UTPServer *p;
-    QList<net::ServerSocket::Ptr> sockets;
+    std::vector<net::ServerSocket::Ptr> sockets;
     bool running;
     QMap<quint16, Connection::Ptr> connections;
     UTPServerThread *utp_thread;
@@ -92,7 +94,7 @@ public:
     bool create_sockets;
     bt::Uint8 tos;
     OutputQueue output_queue;
-    QList<mse::EncryptedPacketSocket::Ptr> pending;
+    std::vector<std::unique_ptr<mse::EncryptedPacketSocket>> pending;
     QMutex pending_mutex;
     MainThreadCall *mtc;
     QList<Connection::WPtr> last_accepted;
